@@ -1,13 +1,13 @@
 from functools import wraps
 
 from wedeliver_core import WeDeliverCore
-from wedeliver_core.wedeliver_core.app_decorators import (
+from wedeliver_core.app_decorators import (
     handle_response,
     handle_auth,
     handle_exceptions,
     serializer,
 )
-from wedeliver_core.wedeliver_core.helpers.get_prefix import get_prefix
+from wedeliver_core.helpers.get_prefix import get_prefix
 
 
 def route(path, methods=["GET"], schema=None, many=False, allowed_roles=None, require_auth=True,
