@@ -6,7 +6,7 @@ from flask import request
 from marshmallow import ValidationError
 from sqlalchemy.orm.exc import UnmappedInstanceError
 
-from wedeliver_core.wedeliver_core.helpers.exceptions import AppValidationError
+from wedeliver_core.helpers.exceptions import AppValidationError
 
 
 def is_mapped(obj):
