@@ -2,26 +2,26 @@ import platform
 from datetime import datetime
 
 from .kafka_producer import Producer
+from ... import WeDeliverCore
 
 INTERNAL_NOTIFICATION_MESSAGE = "internal_notification_message"
 
 
-def send_critical_error(message, channel=None, app=None):
+def send_critical_error(message, channel=None):
     channel = channel or "critical-errors"
     send_notification_message(
         channel=channel,
         title="critical",
         color="#df0000",
         message=message,
-        emoji=":pleading_face:",
-        app=app
+        emoji=":pleading_face:"
     )
 
 
 def send_notification_message(
-    message, channel="logs", title="Log", color="#32a4a7", emoji=":dizzy_face:", app=None
+        message, channel="logs", title="Log", color="#32a4a7", emoji=":dizzy_face:"
 ):
-    # print(channel)
+    app = WeDeliverCore.getApp()
     channel = "eng-{0}-{1}".format(
         app.config.get("FLASK_ENV")
         if app.config.get("FLASK_ENV") == "production"
